@@ -1,6 +1,3 @@
-import os
-import sys
-import glob
 import argparse
 import logging
 
@@ -9,10 +6,9 @@ from billy.utils import configure_logging
 from billy.commands import BaseCommand
 
 logger = logging.getLogger('billy')
-configure_logging(1)
+configure_logging()
 
 COMMAND_MODULES = (
-    'billy.commands.district_csv_stub',
     'billy.commands.dump',
     'billy.commands.load_legislators',
     'billy.commands.oysterize',
@@ -22,9 +18,9 @@ COMMAND_MODULES = (
     'billy.commands.update_external_ids',
     'billy.commands.update_leg_ids',
     'billy.commands.validate_api',
-    'billy.commands.jenkins',
 )
 
+
 def import_command_module(mod):
     try:
         __import__(mod)
@@ -32,6 +28,7 @@ def import_command_module(mod):
         logger.warning(
             'error "{0}" prevented loading of {1} module'.format(e, mod))
 
+
 def main():
     parser = argparse.ArgumentParser(description='generic billy util',
                                      parents=[base_arg_parser])
@@ -49,7 +46,7 @@ def main():
     # parse arguments, update settings, then run the appropriate function
     args = parser.parse_args()
     settings.update(args)
-    configure_logging(args.verbose)
+    configure_logging(args.subcommand)
     subcommands[args.subcommand].handle(args)
 
 if __name__ == '__main__':
