@@ -2,16 +2,20 @@ import os
 import re
 import time
 import json
-import logging
 import datetime
-from collections import defaultdict
 
 from pymongo.son import SON
 import pymongo.errors
+import name_tools
 
 from billy import db
 
-import name_tools
+oyster_import_exception = None
+try:
+    from oyster.core import kernel
+except Exception as e:
+    kernel = None
+    oyster_import_exception = e
 
 
 def _get_property_dict(schema):
@@ -70,7 +74,10 @@ def insert_with_id(obj):
         new_id = 1
 
     while True:
-        obj['_id'] = '%s%06d' % (id_prefix, new_id)
+        if obj['_type'] == 'bill':
+            obj['_id'] = '%s%08d' % (id_prefix, new_id)
+        else:
+            obj['_id'] = '%s%06d' % (id_prefix, new_id)
         obj['_all_ids'] = [obj['_id']]
 
         if obj['_type'] in ['person', 'legislator']:
@@ -130,7 +137,6 @@ def update(old, new, collection, sneaky_update_filter=None):
                 old[key] = value
                 need_save = True
 
-
         # remove old +key field if this field no longer has a +
         plus_key = '+%s' % key
         if plus_key in old:
@@ -228,6 +234,7 @@ def prepare_obj(obj):
 
     return make_plus_fields(obj)
 
+
 def next_big_id(abbr, letter, collection):
     query = SON([('_id', abbr)])
     update = SON([('$inc', SON([('seq', 1)]))])
@@ -238,6 +245,7 @@ def next_big_id(abbr, letter, collection):
                           ('upsert', True)]))['value']['seq']
     return "%s%s%08d" % (abbr.upper(), letter, seq)
 
+
 def merge_legislators(leg1, leg2):
     assert leg1['_id'][:3] == leg2['_id'][:3]
     assert leg1['_id'] != leg2['_id']
@@ -247,11 +255,11 @@ def merge_legislators(leg1, leg2):
     leg1 = leg1.copy()
     leg2 = leg2.copy()
 
-    roles     = 'roles'
+    roles = 'roles'
     old_roles = 'old_roles'
 
     no_compare = set(('_id', 'leg_id', '_all_ids', '_locked_fields',
-        'created_at', 'updated_at', roles, old_roles ))
+        'created_at', 'updated_at', roles, old_roles))
 
     leg1['_all_ids'] += leg2['_all_ids']
 
@@ -282,21 +290,27 @@ def merge_legislators(leg1, leg2):
         # WARNING: This code *WILL* drop current ctty appointments.
         #  What this means:
         #      In the case where someone goes from chamber L->U, and is on
-        #      joint-ctty A, moves to U, we will *LOOSE* joint-ctty from 
+        #      joint-ctty A, moves to U, we will *LOOSE* joint-ctty from
         #      old_roles & roles!! There's a potenital for data loss, but it's
         #      not that big of a thing.
         #   -- paultag & jamesturk, 02-02-2012
         crole = leg1[roles][0]
         try:
-            leg1[old_roles][crole['term']].append( crole )
+            leg1[old_roles][crole['term']].append(crole)
         except KeyError:
             try:
                 leg1[old_roles][crole['term']] = [crole]
             except KeyError:
                 # dear holy god this needs to be fixed.
-                leg1[old_roles] = { crole['term'] : [ crole ] }
+                leg1[old_roles] = {crole['term']: [crole]}
 
         # OK. We've migrated the newly old roles to the old_roles entry.
-        leg1[roles] = [ leg2[roles][0] ]
-    return ( leg1, leg2['_id'] )
+        leg1[roles] = [leg2[roles][0]]
+    return (leg1, leg2['_id'])
 
+
+def oysterize(url, doc_class, id, **kwargs):
+    if not kernel:
+        raise oyster_import_exception
+    # kwargs pass through as metadata
+    kernel.track_url(url, doc_class, id=id, **kwargs)
