@@ -94,7 +94,7 @@ class BillyHandlerMetaClass(HandlerMetaClass):
             def new_read(*args, **kwargs):
                 request = args[1]
                 fmt = request.GET.get('format')
-                if fmt in ['xml', 'rss', 'ics'] and 'fields' in request.GET:
+                if fmt in ['xml', 'ics'] and 'fields' in request.GET:
                     resp = rc.BAD_REQUEST
                     resp.write(": cannot specify fields param if format=%s" %
                                fmt)
@@ -123,9 +123,9 @@ class BillyHandler(BaseHandler):
 
 class AllMetadataHandler(BillyHandler):
     def read(self, request):
-        data = db.metadata.find(fields={'level':1, 'abbreviation':1,
-                                        'name':1, 'feature_flags': 1,
-                                        '_id':0}).sort('name')
+        data = db.metadata.find(fields={'level': 1, 'abbreviation': 1,
+                                        'name': 1, 'feature_flags': 1,
+                                        '_id': 0}).sort('name')
         return list(data)
 
 
@@ -204,7 +204,7 @@ class BillSearchHandler(BillyHandler):
         if sponsor_id:
             _filter['sponsors.leg_id'] = sponsor_id
 
-
+        # limit response size
         count = db.bills.find(_filter, bill_fields).count()
         if count > 5000:
             resp = rc.BAD_REQUEST
@@ -269,31 +269,6 @@ class CommitteeSearchHandler(BillyHandler):
         return list(db.committees.find(_filter, committee_fields))
 
 
-class StatsHandler(BillyHandler):
-    def read(self, request):
-        counts = {}
-
-        # db.bill_stats contains the output of a m/r run that generates counts
-        # of bills and bill sub-objects
-        for count in db.bill_stats.find():
-            val = count['value']
-            abbr = count['_id']
-
-            if abbr == 'total':
-                val['legislators'] = db.legislators.count()
-            else:
-                level = metadata(abbr)['level']
-                val['legislators'] = db.legislators.find({'level': level,
-                                                          level: abbr}).count()
-
-            counts[abbr] = val
-
-        stats = db.command('dbStats')
-        stats['counts'] = counts
-
-        return stats
-
-
 class EventsHandler(BillyHandler):
     def read(self, request, id=None, events=[]):
         if events:
@@ -551,7 +526,6 @@ class BoundaryHandler(BillyHandler):
     base_url = getattr(settings, 'BOUNDARY_SERVICE_URL',
                        'http://localhost:8001/1.0/')
 
-
     def read(self, request, boundary_id):
         url = "%sboundary/%s/?shape_type=simple" % (self.base_url, boundary_id)
         try:
