@@ -1,6 +1,6 @@
 import datetime
 from django.conf import settings
-from django.conf.urls.defaults import *
+from django.conf.urls.defaults import patterns, url
 from django.http import HttpResponse
 
 import piston.resource
@@ -8,8 +8,8 @@ from piston.emitters import Emitter
 
 from billy.site.api import handlers
 from billy.site.api.views import legislator_preview
-from billy.site.api.emitters import BillyJSONEmitter, BillyXMLEmitter
-from billy.site.api.emitters import FeedEmitter, ICalendarEmitter
+from billy.site.api.emitters import BillyJSONEmitter
+from billy.site.api.emitters import ICalendarEmitter
 
 if getattr(settings, 'USE_LOCKSMITH', False):
     from locksmith.mongoauth.authentication import PistonKeyAuthentication
@@ -42,12 +42,11 @@ else:
     Resource = piston.resource.Resource
 
 Emitter.register('json', BillyJSONEmitter, 'application/json; charset=utf-8')
-Emitter.register('xml', BillyXMLEmitter, 'application/xml; charset=utf-8')
 
-Emitter.register('rss', FeedEmitter, 'application/rss+xml')
 Emitter.register('ics', ICalendarEmitter, 'text/calendar')
 
 Emitter.unregister('yaml')
+Emitter.unregister('xml')
 Emitter.unregister('django')
 Emitter.unregister('pickle')
 
@@ -67,8 +66,6 @@ committee_handler = Resource(handlers.CommitteeHandler,
                              authentication=authorizer)
 committee_search_handler = Resource(handlers.CommitteeSearchHandler,
                                     authentication=authorizer)
-stats_handler = Resource(handlers.StatsHandler,
-                         authentication=authorizer)
 events_handler = Resource(handlers.EventsHandler,
                           authentication=authorizer)
 subject_list_handler = Resource(handlers.SubjectListHandler,
@@ -120,7 +117,4 @@ urlpatterns = patterns('',
     url(r'v1/districts/(?P<abbr>[a-zA-Z]{2})/(?P<chamber>upper|lower)/$',
         district_handler),
     url(r'v1/districts/boundary/(?P<boundary_id>.+)/$', boundary_handler),
-
-
-    url(r'^v1/stats/$', stats_handler),
 )
