@@ -1,5 +1,4 @@
 import re
-import pdb
 import json
 import time
 import types
@@ -11,12 +10,14 @@ import functools
 import unicodecsv
 from operator import itemgetter
 from itertools import chain, imap
-from collections import defaultdict
+from collections import defaultdict, OrderedDict
+
+from pymongo.objectid import ObjectId
 
 from django.http import Http404, HttpResponse
 from django.template.loader import render_to_string
 from django.views.decorators.cache import never_cache
-from django.shortcuts import render, render_to_response
+from django.shortcuts import render
 
 from billy import db
 from billy.utils import metadata, find_bill
@@ -24,43 +25,60 @@ from billy.scrape import JSONDateEncoder
 from billy.importers.utils import merge_legislators
 
 
+def _meta_and_report(abbr):
+    meta = metadata(abbr)
+    report = db.reports.find_one({'_id': abbr})
+    if not meta or not report:
+        raise Http404
+    return meta, report
+
+
 def keyfunc(obj):
     try:
         return int(obj['district'])
     except ValueError:
         return obj['district']
 
-def _csv_response(request, template, data):
+
+def _csv_response(request, csv_name, columns, data, abbr):
     if 'csv' in request.REQUEST:
         resp = HttpResponse(mimetype="text/plain")
+        resp['Content-Disposition'] = 'attachment; filename=%s_%s.csv' % (
+            abbr, csv_name)
         out = unicodecsv.writer(resp)
         for item in data:
             out.writerow(item)
         return resp
     else:
-        return render(request, template, {'data':data})
+        return render(request, 'billy/generic_table.html',
+                      {'columns': columns,
+                       'data':data, 'metadata': metadata(abbr)})
+
 
 def browse_index(request, template='billy/index.html'):
     rows = []
 
-    for report in db.reports.find():
+    spec = {}
+    only = request.GET.get('only', [])
+    if only:
+        spec = {'_id': {'$in': only.split(',')}}
+
+    for report in db.reports.find(spec):
         report['id'] = report['_id']
         meta = db.metadata.find_one({'_id': report['_id']})
         report['name'] = meta['name']
+        report['unicameral'] = ('lower_chamber_name' not in meta)
         report['bills']['typed_actions'] = (100 -
-                                report['bills']['actions_per_type'].get('other', 100))
+            report['bills']['actions_per_type'].get('other', 100))
         rows.append(report)
 
     rows.sort(key=lambda x: x['name'])
 
-    return render(request, template, {'rows': rows, 'nocontainer' : True})
+    return render(request, template, {'rows': rows})
+
 
 def overview(request, abbr):
-    meta = metadata(abbr)
-    report = db.reports.find_one({'_id': abbr})
-    if not meta or not report:
-        raise Http404
-
+    meta, report = _meta_and_report(abbr)
     context = {}
     context['metadata'] = meta
     context['report'] = report
@@ -70,15 +88,14 @@ def overview(request, abbr):
             "scraped.state" : abbr
         }).sort( "scraped.started", direction=pymongo.DESCENDING )[0]
         # This hack brought to you by Django's inability to do subtraction
-        # in the templte :)
-        runlog['scraped']['time_delta'] = ( runlog['scraped']['ended'] - \
-                                          runlog['scraped']['started'] )
+        # in the template :)
+        runlog['scraped']['time_delta'] = (runlog['scraped']['ended'] -
+                                           runlog['scraped']['started'])
         context['runlog'] = runlog
         if "failure" in runlog:
             context['warning_title'] = "This build is currently broken!"
-            context['warning'] = \
-"""
-The last scrape was a failre. Check in the run log secion for more details,
+            context['warning'] = """
+The last scrape was a failure. Check in the run log section for more details,
 or check out the scrape run report page for this state.
 """
     except IndexError:
@@ -86,7 +103,9 @@ or check out the scrape run report page for this state.
 
     return render(request, 'billy/state_index.html', context)
 
+
 def run_detail_graph_data(request, abbr):
+
     def rolling_average( oldAverage, newItem, oldAverageCount ):
         """
         Simple, unweighted rolling average. If you don't get why we have
@@ -133,7 +152,7 @@ def run_detail_graph_data(request, abbr):
 
                     delt = ( g['end_time'] - g['start_time'] ).total_seconds()
                     ret[field].append(delt)
-                except KeyError:
+                except KeyError: # XXX: THIS MESSES STUFF UP. REVISE.
                     ret[field].append(0)
         l = []
         for line in fields:
@@ -174,25 +193,25 @@ def run_detail_graph_data(request, abbr):
             "type" : "stacked",
             "spec" : {}
         },
-        "default" : { "run" : _do_digest,
-            "title" : "Last %s runs" % ( history_count ),
-            "type" : "lines",
-            "spec" : {}
-        },
-        "clean"   : { "run" : _do_digest,
-            "title" : "Last %s non-failed runs" % ( history_count ),
-            "type" : "lines",
-            "spec" : {
-                "failure" : { "$exists" : False }
-            }
-        },
-        "failure"   : { "run" : _do_digest,
-            "title" : "Last %s failed runs" % ( history_count ),
-            "type" : "lines",
-            "spec" : {
-                "failure" : { "$exists" : True  }
-            }
-        },
+        #"default" : { "run" : _do_digest,
+        #    "title" : "Last %s runs" % ( history_count ),
+        #    "type" : "lines",
+        #    "spec" : {}
+        #},
+        #"clean"   : { "run" : _do_digest,
+        #    "title" : "Last %s non-failed runs" % ( history_count ),
+        #    "type" : "lines",
+        #    "spec" : {
+        #        "failure" : { "$exists" : False }
+        #    }
+        #},
+        #"failure"   : { "run" : _do_digest,
+        #    "title" : "Last %s failed runs" % ( history_count ),
+        #    "type" : "lines",
+        #    "spec" : {
+        #        "failure" : { "$exists" : True  }
+        #    }
+        #},
         "falure-pie": { "run" : _do_pie,
             "title" : "Digest of what exceptions have been thrown",
             "type" : "pies",
@@ -216,10 +235,39 @@ def run_detail_graph_data(request, abbr):
         content_type="text/plain"
     )
 
-def run_detail(request, abbr):
-    runlog = db.billy_runs.find({
-        "scraped.state" : abbr
-    }).sort( "scraped.started", direction=pymongo.DESCENDING )[0]
+
+def run_detail(request, obj=None):
+    try:
+        run = db.billy_runs.find({
+            "_id" : ObjectId(obj)
+        })[0]
+    except IndexError as e:
+        return render(request, 'billy/run_empty.html', {
+            "warning" : "No records exist. Fetch returned a(n) %s" % (
+                    e.__class__.__name__
+            )
+        })
+    return render(request, 'billy/run_detail.html', {
+        "run" : run,
+        "metadata" : {
+            "abbreviation" : run['state'],
+            "name"         : run['state']
+        }
+    })
+
+
+def state_run_detail(request, abbr):
+    try:
+        allruns = db.billy_runs.find({
+            "scraped.state" : abbr
+        }).sort( "scraped.started", direction=pymongo.DESCENDING )[:25]
+        runlog = allruns[0]
+    except IndexError as e:
+        return render(request, 'billy/run_empty.html', {
+            "warning" : "No records exist. Fetch returned a(n) %s" % (
+                    e.__class__.__name__
+            )
+        })
 
     # pre-process goodies for the template
     runlog['scraped']['t_delta'] = (
@@ -232,8 +280,10 @@ def run_detail(request, abbr):
             )
 
     context = {
-        "runlog" : runlog,
-        "state"  : abbr
+        "runlog"   : runlog,
+        "allruns"  : allruns,
+        "state"    : abbr,
+        "metadata" : metadata(abbr),
     }
 
     if "failure" in runlog:
@@ -244,58 +294,170 @@ This build had an exception during it's execution. Please check below
 for the exception and error message.
 """
 
-    return render(request, 'billy/run_detail.html', context)
+    return render(request, 'billy/state_run_detail.html', context)
+
 
 @never_cache
 def bills(request, abbr):
+    meta, report = _meta_and_report(abbr)    
 
-    meta = metadata(abbr)
-
-    report = db.reports.find_one({'_id': abbr})
-    if not report:
-        raise Http404
+    terms = list(chain.from_iterable(map(itemgetter('sessions'), 
+                                         meta['terms'])))
+    def sorter(item, index=terms.index, len_=len(terms)):
+        '''Sort session strings in order described in state's metadata.'''
+        session, data = item
+        return index(session)
 
+    # Convert sessions into an ordered dict.
     sessions = report['bills']['sessions']
+    sessions = sorted(sessions.items(), key=sorter)
+    sessions = OrderedDict(sessions)
 
+    def decimal_format(value, TWOPLACES=decimal.Decimal(100) ** -1):
+        '''Format a float like 2.2345123 as a decimal like 2.23'''
+        n = decimal.Decimal(str(value))
+        n = n.quantize(TWOPLACES)#, context=Context(traps=[Inexact]))
+        return unicode(n)
 
     # ------------------------------------------------------------------------
-    # Get data for the tables for counts, types, etc. 
+    # Define data for the tables for counts, types, etc. 
     tablespecs = [
-        ('Bill Counts',      {'rownames': ['upper_count','lower_count',
-                                      'version_count', 'versionless_count']}),
-        ('Bill Types',       {'keypath': ['bill_types']}),
-        ('Actions by Type',  {'keypath': ['actions_per_type']}),
-        ('Actions by Actor', {'keypath': ['actions_per_actor']}),
-    ]
+        ('Bill Counts', {'rownames': [
+                                 'upper_count','lower_count',
+                                 'version_count']}),
 
+        ('Bill Types', {
+            'keypath': ['bill_types'],       
+            'summary': {
+                'object_type': 'bills',
+                'key': 'type',
+                },
+            }),
+
+        ('Actions by Type', {
+            'keypath': ['actions_per_type'],
+            'summary': {
+                'object_type': 'actions',
+                'key': 'type',
+                },
+            }),
+
+        ('Actions by Actor', {
+            'keypath': ['actions_per_actor'],
+            'summary': {
+                'object_type': 'actions',
+                'key': 'actor',
+                },
+            }),
+        ('Quality Issues',   {'rownames': [
+                                 'sourceless_count', 'sponsorless_count',
+                                 'actionless_count', 'actions_unsorted',
+                                 'bad_vote_counts', 'version_count',
+                                 'versionless_count', 
+
+                                 'sponsors_with_leg_id', 
+                                 'rollcalls_with_leg_id',
+                                 'have_subjects',
+                                 'updated_this_year',
+                                 'updated_this_month',
+                                 'updated_today',
+                                 'vote_passed']}),
+        ]
+
+    format_as_percent = [
+        'sponsors_with_leg_id', 
+        'rollcalls_with_leg_id',
+        'have_subjects',
+        'updated_this_year',
+        'updated_this_month',
+        'updated_today',
+        'actions_per_actor',
+        'actions_per_type']
+
+    # Create the data for each table.
     tables = []
-
     for name, spec in tablespecs:
-
         column_names = []
         rows = defaultdict(list)
-        tabledata = {'title': name,
+        href_params = {}
+        tabledata = {'abbr': abbr,
+                     'title': name,
                      'column_names': column_names,
                      'rows': rows}
+        contexts = []
+
         for session, context in sessions.items():
+            column_names.append(session)
             if 'keypath' in spec:
                 for k in spec['keypath']:
                     context = context[k]
-            column_names.append(session)
-            rownames = spec.get('rownames', context)
+            contexts.append(context)
+
+        try:
+            rownames = spec['rownames']
+        except KeyError:
+            rownames = reduce(lambda x, y: set(x) | set(y), contexts)
+
+        for context in contexts:        
             for r in rownames:
-                rows[r].append(context[r])
-        tabledata['rows'] = dict(rows)
+
+                val = context.get(r, 0)
+                if not isinstance(val, (int, float, decimal.Decimal)):
+                    val = len(val)    
+
+                use_percent = any([
+                    r in format_as_percent, 
+                    name in ['Actions by Actor', 'Actions by Type'],
+                    ])
+
+                if use_percent and (val != 0):
+                    val = decimal_format(val)
+                    val += ' %'
+                rows[r].append(val)
+
+                # Link to summary/distint views. 
+                if 'summary' in spec:
+                    try:
+                        spec_key = '.'.join(spec['keypath'])
+                    except KeyError:
+                        spec_key = r
+
+                    try:
+                        spec_val = spec['spec'](r)
+                    except KeyError:
+                        spec_val = r
+                    else:
+                        spec_val = json.dumps(spec_val)
+
+                    params = dict(spec['summary'], session=session, 
+                                  val=spec_val)
+
+                    params = urllib.urlencode(params)
+                    href_params[r] = params
+
+        # Add the final "total" column.
+        tabledata['column_names'].append('Total')
+        for k, v in rows.items():
+            try:
+                sum_ = sum(v)
+            except TypeError:
+                sum_ = 'n/a'
+            v.append(sum_)
+
+        rowdata = [((r, href_params.get(r)), cells) for (r, cells) in rows.items()]
+        tabledata['rowdata'] = rowdata
+
         tables.append(tabledata)
 
     # ------------------------------------------------------------------------
     # Render the tables.
-    render = functools.partial(render_to_string, 'billy/bills_table.html')
-    tables = map(render, tables)
+    _render = functools.partial(render_to_string, 'billy/bills_table.html')
+    tables = map(_render, tables)
+
+    return render(request, "billy/bills.html",
+                  dict(tables=tables, metadata=meta, sessions=sessions,
+                       tablespecs=tablespecs))
 
-    return render_to_response( "billy/bills.html",
-                              dict(tables=tables, metadata=meta,
-                                   sessions=sessions))
 
 def summary_index(request, abbr):
 
@@ -364,7 +526,8 @@ def summary_object_key(request, abbr, urlencode=urllib.urlencode,
     total = len(counter)
     objs = sorted(counter, key=counter.get, reverse=True)
     objs = ((obj, counter[obj], counter[obj]/total, params(obj)) for obj in objs)
-    return rendert(request, 'billy/summary_object_key.html', locals())
+    return render(request, 'billy/summary_object_key.html', locals())
+
 
 def summary_object_key_vals(request, abbr, urlencode=urllib.urlencode,
                             collections=("bills", "legislators", "committees")):
@@ -372,7 +535,14 @@ def summary_object_key_vals(request, abbr, urlencode=urllib.urlencode,
     session = request.GET['session']
     object_type = request.GET['object_type']
     key = request.GET['key']
-    val = json.loads(request.GET['val'])
+
+    val = request.GET['val']
+    try:
+        val = json.loads(val)
+    except ValueError:
+        pass
+
+    
     spec = {'state': abbr, 'session': session}
     fields = {'_id': 1}
 
@@ -389,6 +559,7 @@ def summary_object_key_vals(request, abbr, urlencode=urllib.urlencode,
 
     return render(request, 'billy/summary_object_keyvals.html', locals())
 
+
 def object_json(request, collection, _id,
                 re_attr=re.compile(r'^    "(.{1,100})":', re.M)):
 
@@ -404,6 +575,7 @@ def object_json(request, collection, _id,
     obj_json = json.dumps(obj, cls=JSONDateEncoder, indent=4)
     keys = sorted(obj)
 
+
     def subfunc(m, tmpl='    <a name="%s">%s:</a>'):
         val = m.group(1)
         return tmpl % (val, val)
@@ -421,8 +593,8 @@ def other_actions(request, abbr):
     report = db.reports.find_one({'_id': abbr})
     if not report:
         raise Http404
-    return _csv_response(request, 'billy/other_actions.html',
-                         sorted(report['bills']['other_actions']))
+    return _csv_response(request, 'other_actions', ('action', '#'),
+                         sorted(report['bills']['other_actions']), abbr)
 
 
 def unmatched_leg_ids(request, abbr):
@@ -434,8 +606,8 @@ def unmatched_leg_ids(request, abbr):
     com_unmatched = set(tuple(i) for i in
                          report['committees']['unmatched_leg_ids'])
     combined_sets = bill_unmatched | com_unmatched
-    return _csv_response(request, 'billy/unmatched_leg_ids.html',
-                         sorted(combined_sets))
+    return _csv_response(request, 'leg_ids', ('term', 'chamber', 'name'),
+                         sorted(combined_sets), abbr)
 
 def uncategorized_subjects(request, abbr):
     report = db.reports.find_one({'_id': abbr})
@@ -443,8 +615,44 @@ def uncategorized_subjects(request, abbr):
         raise Http404
     subjects = sorted(report['bills']['uncategorized_subjects'],
                       key=lambda t: (t[1],t[0]), reverse=True)
-    return _csv_response(request, 'billy/uncategorized_subjects.html',
-                         subjects)
+    return _csv_response(request, 'uncategorized_subjects', ('subject', '#'),
+                         subjects, abbr)
+
+def district_stub(request, abbr):
+    def keyfunc(x):
+        try:
+            district = int(x[2])
+        except ValueError:
+            district = x[2]
+        return x[1], district
+
+    fields = ('abbr', 'chamber', 'name', 'num_seats', 'boundary_id')
+
+    counts = defaultdict(int)
+    for leg in db.legislators.find({'state': abbr, 'active': True}):
+        if 'chamber' in leg:
+            counts[(leg['chamber'], leg['district'])] += 1
+
+    data = []
+    for key, count in counts.iteritems():
+        chamber, district =  key
+        data.append((abbr, chamber, district, count, ''))
+
+    data.sort(key=keyfunc)
+
+    return _csv_response(request, "districts",
+                         ('abbr', 'chamber', 'district', 'count', ''),
+                         data, abbr)
+
+
+def duplicate_versions(request, abbr):
+    meta, report = _meta_and_report(abbr)
+
+    data = report['bills']['duplicate_versions']
+
+    return render(request, "billy/duplicate_versions.html",
+                  {'metadata': meta, 'report': report})
+
 
 @never_cache
 def random_bill(request, abbr):
@@ -475,7 +683,8 @@ def random_bill(request, abbr):
     }
 
     if modi_flag == 'bad_vote_counts':
-        bad_vote_counts = db.reports.find_one({'_id': abbr})['bills']['bad_vote_counts']
+        bad_vote_counts = db.reports.find_one({'_id': abbr}
+                                             )['bills']['bad_vote_counts']
         spec = {'_id': {'$in': bad_vote_counts}}
         default = False
 
@@ -484,6 +693,13 @@ def random_bill(request, abbr):
         spec.update( basic_specs[modi_flag] )
         spec.pop('session') # all sessions
 
+    if modi_flag == 'current_term':
+        default = False
+        curTerms = meta['terms'][-1]['sessions']
+        spec['session'] = {
+            "$in" : curTerms
+        }
+
     count = db.bills.find(spec).count()
     if count:
         bill = db.bills.find(spec)[random.randint(0, count - 1)]
@@ -492,12 +708,19 @@ def random_bill(request, abbr):
         bill = None
         warning = 'No bills matching the criteria were found.'
 
+    try:
+        bill_id = bill['_id']
+    except TypeError:
+        # Bill was none (see above).
+        bill_id = None
 
     context = {
         'bill'   : bill,
+        'id': bill_id,
         'random' : True,
         'state' : abbr.lower(),
         'warning': warning,
+        'metadata': meta,
     }
 
     if default and modi_flag != "":
@@ -512,26 +735,38 @@ def random_bill(request, abbr):
     return render(request, 'billy/bill.html', context)
 
 
+def bill_list(request, abbr):
+    meta = metadata(abbr)
+    if not meta:
+        raise Http404
+
+    level = meta['level']
+    spec = {'level': level, level: abbr}
+
+    if 'version_url' in request.GET:
+        version_url = request.GET.get('version_url')
+        spec['versions.url'] = version_url
+
+    bills = db.bills.find(spec)
+    query_text = repr(spec)
+
+    context = {'metadata': meta,
+               'query_text': query_text,
+               'bills': bills}
+
+    return render(request, 'billy/bill_list.html', context)
+
+
 def bill(request, abbr, session, id):
-    level = metadata(abbr)['level']
+    meta = metadata(abbr)
+    level = meta['level']
     bill = find_bill({'level': level, level: abbr,
                       'session':session, 'bill_id':id.upper()})
     if not bill:
         raise Http404
 
-    return render(request, 'billy/bill.html', {'bill': bill})
-
-
-def bill_json(request, abbr, session, id):
-    level = metadata(abbr)['level']
-    bill = find_bill({'level': level, level: abbr,
-                      'session':session, 'bill_id':id.upper()})
-    if not bill:
-        raise Http404
-
-    _json = json.dumps(bill, cls=JSONDateEncoder, indent=4)
-
-    return render(request, 'billy/bill_json.html', {'json': _json})
+    return render(request, 'billy/bill.html',
+                  {'bill': bill, 'metadata': meta, 'id': bill['_id']})
 
 
 def legislators(request, abbr):
